@@ -19,7 +19,7 @@ tit = """
 ██╔═══╝   ╚██╔╝  ██║     ██║▄▄ ██║██╔══██╗██║   ██║   ██║   
 ██║        ██║   ╚██████╗╚██████╔╝██████╔╝╚██████╔╝   ██║   
 ╚═╝        ╚═╝    ╚═════╝ ╚══▀▀═╝ ╚═════╝  ╚═════╝    ╚═╝   
-                                            v0.4.4  BY FengLiu
+                                            v0.4.4.1  BY FengLiu
 #################################################################
 """
 
